@@ -1,5 +1,5 @@
 /*
- *	$Id: pciutils.h,v 1.3 1998/02/09 12:32:56 mj Exp $
+ *	$Id: pciutils.h,v 1.4 1998/03/31 21:02:18 mj Exp $
  *
  *	Linux PCI Utilities -- Declarations
  *
@@ -16,6 +16,8 @@
 #include "pci.h"
 #endif
 
+#define PCIUTILS_VERSION "1.04"
+
 #define PROC_BUS_PCI "/proc/bus/pci"
 #define ETC_PCI_IDS "/etc/pci.ids"
 
@@ -38,3 +40,15 @@ char *lookup_vendor(word);
 char *lookup_device(word, word);
 char *lookup_device_full(word, word);
 char *lookup_class(word);
+
+/* filter.c */
+
+struct pci_filter {
+  int bus, slot, func;			/* -1 = ANY */
+  int vendor, device;
+};
+
+void filter_init(struct pci_filter *);
+char *filter_parse_slot(struct pci_filter *, char *);
+char *filter_parse_id(struct pci_filter *, char *);
+int filter_match(struct pci_filter *, byte bus, byte devfn, word vendid, word devid);
